@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Dict
 
 import datahub.emitter.mce_builder as builder
 import datahub.metadata.schema_classes as models
@@ -53,7 +53,7 @@ class Dashboard(Entity):
         owners: List[str] = None,
         glossary_terms: List[str] = None,
         url: str = None,
-        links: dict[str, str] = None,
+        links: Dict[str, str] = None,
         platform: str = "datastudio",
     ) -> List[dict]:
         """Create a dashboard mpc.
